"use client";
import Link from "next/link";
import { useEffect, useState } from "react";
import { Alert, Button } from "react-bootstrap";

const CURRENT_VERSION = "v1.8.4";

export default function UpdateNotification() {
    const [displayPrompt, setDisplayPrompt] = useState(false);

    const closePrompt = () => {
        setDisplayPrompt(false);
    };

    const doNotShowAgain = () => {
        // Create date 1 year from now
        const date = new Date();
        date.setFullYear(date.getFullYear() + 1);
        localStorage.setItem(
            "updateNotificationPrompt",
            JSON.stringify({
                dontShow: true,
                version: CURRENT_VERSION,
                date: date.toISOString(),
            }),
        );
        setDisplayPrompt(false);
    };

    useEffect(() => {
        const prompt = localStorage.getItem("updateNotificationPrompt");
        if (prompt) {
            const { dontShow, version } = JSON.parse(prompt);
            if (dontShow && version === CURRENT_VERSION) {
                setDisplayPrompt(false);
            } else {
                setDisplayPrompt(true);
            }
        } else {
            setDisplayPrompt(true);
        }
    }, []);

    return (
        <Alert variant="info" className="mx-2 py-2" show={displayPrompt}>
            <Alert.Heading
                style={{
                    fontSize: "1.1rem",
                    fontWeight: "bold",
                    marginBottom: "0.25rem",
                }}
            >
                Update Notification {CURRENT_VERSION}
            </Alert.Heading>
            <div className="mb-2">
                We&apos;re happy to announce that snip had a minor updated to{" "}
                <b>{CURRENT_VERSION}</b> featuring some small fixes and enhanced
                support for the{" "}
                <Link href="https://snip-python.readthedocs.io/en/latest/">
                    <code>snip-python</code>
                </Link>{" "}
                package. You can find the full list of changes in the{" "}
                <Link
                    href="https://gitlab.gwdg.de/irp/snip/-/blob/main/CHANGELOG.md?ref_type=heads"
                    target="_blank"
                    rel="noopener noreferrer"
                >
                    changelog
                </Link>
                . As always it is possible that some issues may arise because of
                the update. If you encounter any problems, please let us know by
                creating an{" "}
                <Link href="https://gitlab.gwdg.de/irp/snip/-/issues">
                    issue
                </Link>{" "}
                or contacting us at{" "}
                <Link href="mailto:uprpsnip@gwdg.de">uprpsnip@gwdg.de</Link>. We
                appreciate your feedback and will do our best to address any
                issues that arise.
            </div>
            <div className="d-flex justify-content-between">
                <Button
                    className="p-1 d-flex align-items-center gap-1"
                    variant="outline-secondary"
                    onClick={doNotShowAgain}
                >
                    Don&apos;t show again
                </Button>
                <Button
                    className="p-1 d-flex align-items-center gap-1"
                    variant="outline-dark"
                    onClick={closePrompt}
                >
                    Close
                </Button>
            </div>
        </Alert>
    );
}
