"use client";
import { usePreventSwipeGestures } from "lib/hooks/usePreventSwipeGestures";

import type { BookDataRet, PageData } from "@snip/database/types";
import { BaseData, BaseView, SnipData } from "@snip/snips/general/base";

import { EditorContextProvider } from "./context";
import Resizer from "./resizer";
import Sidebar from "./sidebar";
import { Toolbar } from "./tools/toolbar";
import { Tool } from "./tools/types";
import { Viewer } from "./viewer";

export function EditorSinglePageNoSidebar({
    pageData,
}: {
    pageData: PageData;
}) {
    return (
        <EditorContextProvider
            book_id={pageData.book_id}
            pages={[pageData]}
            queuedSnips={[]}
        >
            <Toolbar />
            <Viewer />
        </EditorContextProvider>
    );
}

type Perms = { pRead?: boolean; pWrite?: boolean; pDelete?: boolean };

export function EditorSinglePage({
    bookData,
    pages,
    queuedSnips,
    perms,
}: {
    bookData: BookDataRet;
    pages: PageData[];
    queuedSnips: SnipData<BaseData, BaseView>[];
    perms: Perms;
}) {
    // Parse tools based on the bookData
    const tools = getAllowedTools(perms);
    usePreventSwipeGestures();

    return (
        <EditorContextProvider
            book_id={bookData.id}
            pages={pages}
            queuedSnips={queuedSnips}
        >
            <div id="the_editor" className="d-flex h-100">
                <Sidebar bookData={bookData} init_with_width={false} />
                <Resizer />
                <div className="position-relative">
                    <Toolbar tools={tools} />
                    <Viewer />
                </div>
            </div>
        </EditorContextProvider>
    );
}

function getAllowedTools(perms: Perms) {
    const tools: Tool[] = ["interaction", "movePage"];

    if (perms.pWrite) {
        tools.push("doodle");
        tools.push("text");
        tools.push("placement");
        tools.push("image");
        tools.push("eraser");
    }
    return tools;
}
