#!/bin/bash

echo "[Entrypoint] Starting entrypoint script"
function database_ready() {
    mariadb --host="$MYSQL_HOST" --user="root" --password="$MYSQL_ROOT_PASSWORD" --skip-ssl -e "SELECT 1;" > /dev/null 2>&1
}

# Check that the database is available
if [ -n "$MYSQL_HOST" ]; then
    database=`echo $MYSQL_HOST | awk -F[@//] '{print $4}'`
    echo "[Entrypoint] Waiting for Database ..."
    echo "[Entrypoint] Database host: $MYSQL_HOST"
    while ! database_ready; do
        # Show some progress
        echo -n "."
        sleep 1;
    done
    echo "[Entrypoint] Database is ready"
    # Give it another second
    sleep 1;
    # Run migrations
    echo "[Entrypoint] Running database migrations"
    if node /database/migration_script/bundle/main.js --host $MYSQL_HOST --user root --password "$MYSQL_ROOT_PASSWORD" /database/migration; then
        echo "[Entrypoint] Database migrations complete";
    else
        exit 1;
    fi
else
    echo "\033[0;31m[Entrypoint] No database host provided, this might be a problem!\033[0m"
fi

# Run the main script
echo "[Entrypoint] Starting application npm run $@"
cd ./apps/fullstack
npm run $@
